Documentation
¶
Index ¶
- type PlaybackConfiguration
- type PlaybackConfiguration_AdMarkerPassthrough
- type PlaybackConfiguration_AvailSuppression
- type PlaybackConfiguration_Bumper
- type PlaybackConfiguration_CdnConfiguration
- type PlaybackConfiguration_DashConfiguration
- type PlaybackConfiguration_HlsConfiguration
- type PlaybackConfiguration_LivePreRollConfiguration
- type PlaybackConfiguration_ManifestProcessingRules
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PlaybackConfiguration ¶
type PlaybackConfiguration struct {
// AdDecisionServerUrl AWS CloudFormation Property
// Required: true
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html#cfn-mediatailor-playbackconfiguration-addecisionserverurl
AdDecisionServerUrl string `json:"AdDecisionServerUrl"`
// AvailSuppression AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html#cfn-mediatailor-playbackconfiguration-availsuppression
AvailSuppression *PlaybackConfiguration_AvailSuppression `json:"AvailSuppression,omitempty"`
// Bumper AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html#cfn-mediatailor-playbackconfiguration-bumper
Bumper *PlaybackConfiguration_Bumper `json:"Bumper,omitempty"`
// CdnConfiguration AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html#cfn-mediatailor-playbackconfiguration-cdnconfiguration
CdnConfiguration *PlaybackConfiguration_CdnConfiguration `json:"CdnConfiguration,omitempty"`
// ConfigurationAliases AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html#cfn-mediatailor-playbackconfiguration-configurationaliases
ConfigurationAliases map[string]interface{} `json:"ConfigurationAliases,omitempty"`
// DashConfiguration AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html#cfn-mediatailor-playbackconfiguration-dashconfiguration
DashConfiguration *PlaybackConfiguration_DashConfiguration `json:"DashConfiguration,omitempty"`
// HlsConfiguration AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html#cfn-mediatailor-playbackconfiguration-hlsconfiguration
HlsConfiguration *PlaybackConfiguration_HlsConfiguration `json:"HlsConfiguration,omitempty"`
// LivePreRollConfiguration AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html#cfn-mediatailor-playbackconfiguration-liveprerollconfiguration
LivePreRollConfiguration *PlaybackConfiguration_LivePreRollConfiguration `json:"LivePreRollConfiguration,omitempty"`
// ManifestProcessingRules AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html#cfn-mediatailor-playbackconfiguration-manifestprocessingrules
ManifestProcessingRules *PlaybackConfiguration_ManifestProcessingRules `json:"ManifestProcessingRules,omitempty"`
// Name AWS CloudFormation Property
// Required: true
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html#cfn-mediatailor-playbackconfiguration-name
Name string `json:"Name"`
// PersonalizationThresholdSeconds AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html#cfn-mediatailor-playbackconfiguration-personalizationthresholdseconds
PersonalizationThresholdSeconds *int `json:"PersonalizationThresholdSeconds,omitempty"`
// SlateAdUrl AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html#cfn-mediatailor-playbackconfiguration-slateadurl
SlateAdUrl *string `json:"SlateAdUrl,omitempty"`
// Tags AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html#cfn-mediatailor-playbackconfiguration-tags
Tags []tags.Tag `json:"Tags,omitempty"`
// TranscodeProfileName AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html#cfn-mediatailor-playbackconfiguration-transcodeprofilename
TranscodeProfileName *string `json:"TranscodeProfileName,omitempty"`
// VideoContentSourceUrl AWS CloudFormation Property
// Required: true
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html#cfn-mediatailor-playbackconfiguration-videocontentsourceurl
VideoContentSourceUrl string `json:"VideoContentSourceUrl"`
// AWSCloudFormationDeletionPolicy represents a CloudFormation DeletionPolicy
AWSCloudFormationDeletionPolicy policies.DeletionPolicy `json:"-"`
// AWSCloudFormationUpdateReplacePolicy represents a CloudFormation UpdateReplacePolicy
AWSCloudFormationUpdateReplacePolicy policies.UpdateReplacePolicy `json:"-"`
// AWSCloudFormationDependsOn stores the logical ID of the resources to be created before this resource
AWSCloudFormationDependsOn []string `json:"-"`
// AWSCloudFormationMetadata stores structured data associated with this resource
AWSCloudFormationMetadata map[string]interface{} `json:"-"`
// AWSCloudFormationCondition stores the logical ID of the condition that must be satisfied for this resource to be created
AWSCloudFormationCondition string `json:"-"`
}
PlaybackConfiguration AWS CloudFormation Resource (AWS::MediaTailor::PlaybackConfiguration) See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html
func (*PlaybackConfiguration) AWSCloudFormationType ¶
func (r *PlaybackConfiguration) AWSCloudFormationType() string
AWSCloudFormationType returns the AWS CloudFormation resource type
func (PlaybackConfiguration) MarshalJSON ¶
func (r PlaybackConfiguration) MarshalJSON() ([]byte, error)
MarshalJSON is a custom JSON marshalling hook that embeds this object into an AWS CloudFormation JSON resource's 'Properties' field and adds a 'Type'.
func (*PlaybackConfiguration) UnmarshalJSON ¶
func (r *PlaybackConfiguration) UnmarshalJSON(b []byte) error
UnmarshalJSON is a custom JSON unmarshalling hook that strips the outer AWS CloudFormation resource object, and just keeps the 'Properties' field.
type PlaybackConfiguration_AdMarkerPassthrough ¶
type PlaybackConfiguration_AdMarkerPassthrough struct {
// Enabled AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-admarkerpassthrough.html#cfn-mediatailor-playbackconfiguration-admarkerpassthrough-enabled
Enabled *bool `json:"Enabled,omitempty"`
// AWSCloudFormationDeletionPolicy represents a CloudFormation DeletionPolicy
AWSCloudFormationDeletionPolicy policies.DeletionPolicy `json:"-"`
// AWSCloudFormationUpdateReplacePolicy represents a CloudFormation UpdateReplacePolicy
AWSCloudFormationUpdateReplacePolicy policies.UpdateReplacePolicy `json:"-"`
// AWSCloudFormationDependsOn stores the logical ID of the resources to be created before this resource
AWSCloudFormationDependsOn []string `json:"-"`
// AWSCloudFormationMetadata stores structured data associated with this resource
AWSCloudFormationMetadata map[string]interface{} `json:"-"`
// AWSCloudFormationCondition stores the logical ID of the condition that must be satisfied for this resource to be created
AWSCloudFormationCondition string `json:"-"`
}
PlaybackConfiguration_AdMarkerPassthrough AWS CloudFormation Resource (AWS::MediaTailor::PlaybackConfiguration.AdMarkerPassthrough) See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-admarkerpassthrough.html
func (*PlaybackConfiguration_AdMarkerPassthrough) AWSCloudFormationType ¶
func (r *PlaybackConfiguration_AdMarkerPassthrough) AWSCloudFormationType() string
AWSCloudFormationType returns the AWS CloudFormation resource type
type PlaybackConfiguration_AvailSuppression ¶
type PlaybackConfiguration_AvailSuppression struct {
// Mode AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-availsuppression.html#cfn-mediatailor-playbackconfiguration-availsuppression-mode
Mode *string `json:"Mode,omitempty"`
// Value AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-availsuppression.html#cfn-mediatailor-playbackconfiguration-availsuppression-value
Value *string `json:"Value,omitempty"`
// AWSCloudFormationDeletionPolicy represents a CloudFormation DeletionPolicy
AWSCloudFormationDeletionPolicy policies.DeletionPolicy `json:"-"`
// AWSCloudFormationUpdateReplacePolicy represents a CloudFormation UpdateReplacePolicy
AWSCloudFormationUpdateReplacePolicy policies.UpdateReplacePolicy `json:"-"`
// AWSCloudFormationDependsOn stores the logical ID of the resources to be created before this resource
AWSCloudFormationDependsOn []string `json:"-"`
// AWSCloudFormationMetadata stores structured data associated with this resource
AWSCloudFormationMetadata map[string]interface{} `json:"-"`
// AWSCloudFormationCondition stores the logical ID of the condition that must be satisfied for this resource to be created
AWSCloudFormationCondition string `json:"-"`
}
PlaybackConfiguration_AvailSuppression AWS CloudFormation Resource (AWS::MediaTailor::PlaybackConfiguration.AvailSuppression) See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-availsuppression.html
func (*PlaybackConfiguration_AvailSuppression) AWSCloudFormationType ¶
func (r *PlaybackConfiguration_AvailSuppression) AWSCloudFormationType() string
AWSCloudFormationType returns the AWS CloudFormation resource type
type PlaybackConfiguration_Bumper ¶
type PlaybackConfiguration_Bumper struct {
// EndUrl AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-bumper.html#cfn-mediatailor-playbackconfiguration-bumper-endurl
EndUrl *string `json:"EndUrl,omitempty"`
// StartUrl AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-bumper.html#cfn-mediatailor-playbackconfiguration-bumper-starturl
StartUrl *string `json:"StartUrl,omitempty"`
// AWSCloudFormationDeletionPolicy represents a CloudFormation DeletionPolicy
AWSCloudFormationDeletionPolicy policies.DeletionPolicy `json:"-"`
// AWSCloudFormationUpdateReplacePolicy represents a CloudFormation UpdateReplacePolicy
AWSCloudFormationUpdateReplacePolicy policies.UpdateReplacePolicy `json:"-"`
// AWSCloudFormationDependsOn stores the logical ID of the resources to be created before this resource
AWSCloudFormationDependsOn []string `json:"-"`
// AWSCloudFormationMetadata stores structured data associated with this resource
AWSCloudFormationMetadata map[string]interface{} `json:"-"`
// AWSCloudFormationCondition stores the logical ID of the condition that must be satisfied for this resource to be created
AWSCloudFormationCondition string `json:"-"`
}
PlaybackConfiguration_Bumper AWS CloudFormation Resource (AWS::MediaTailor::PlaybackConfiguration.Bumper) See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-bumper.html
func (*PlaybackConfiguration_Bumper) AWSCloudFormationType ¶
func (r *PlaybackConfiguration_Bumper) AWSCloudFormationType() string
AWSCloudFormationType returns the AWS CloudFormation resource type
type PlaybackConfiguration_CdnConfiguration ¶
type PlaybackConfiguration_CdnConfiguration struct {
// AdSegmentUrlPrefix AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-cdnconfiguration.html#cfn-mediatailor-playbackconfiguration-cdnconfiguration-adsegmenturlprefix
AdSegmentUrlPrefix *string `json:"AdSegmentUrlPrefix,omitempty"`
// ContentSegmentUrlPrefix AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-cdnconfiguration.html#cfn-mediatailor-playbackconfiguration-cdnconfiguration-contentsegmenturlprefix
ContentSegmentUrlPrefix *string `json:"ContentSegmentUrlPrefix,omitempty"`
// AWSCloudFormationDeletionPolicy represents a CloudFormation DeletionPolicy
AWSCloudFormationDeletionPolicy policies.DeletionPolicy `json:"-"`
// AWSCloudFormationUpdateReplacePolicy represents a CloudFormation UpdateReplacePolicy
AWSCloudFormationUpdateReplacePolicy policies.UpdateReplacePolicy `json:"-"`
// AWSCloudFormationDependsOn stores the logical ID of the resources to be created before this resource
AWSCloudFormationDependsOn []string `json:"-"`
// AWSCloudFormationMetadata stores structured data associated with this resource
AWSCloudFormationMetadata map[string]interface{} `json:"-"`
// AWSCloudFormationCondition stores the logical ID of the condition that must be satisfied for this resource to be created
AWSCloudFormationCondition string `json:"-"`
}
PlaybackConfiguration_CdnConfiguration AWS CloudFormation Resource (AWS::MediaTailor::PlaybackConfiguration.CdnConfiguration) See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-cdnconfiguration.html
func (*PlaybackConfiguration_CdnConfiguration) AWSCloudFormationType ¶
func (r *PlaybackConfiguration_CdnConfiguration) AWSCloudFormationType() string
AWSCloudFormationType returns the AWS CloudFormation resource type
type PlaybackConfiguration_DashConfiguration ¶
type PlaybackConfiguration_DashConfiguration struct {
// ManifestEndpointPrefix AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-dashconfiguration.html#cfn-mediatailor-playbackconfiguration-dashconfiguration-manifestendpointprefix
ManifestEndpointPrefix *string `json:"ManifestEndpointPrefix,omitempty"`
// MpdLocation AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-dashconfiguration.html#cfn-mediatailor-playbackconfiguration-dashconfiguration-mpdlocation
MpdLocation *string `json:"MpdLocation,omitempty"`
// OriginManifestType AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-dashconfiguration.html#cfn-mediatailor-playbackconfiguration-dashconfiguration-originmanifesttype
OriginManifestType *string `json:"OriginManifestType,omitempty"`
// AWSCloudFormationDeletionPolicy represents a CloudFormation DeletionPolicy
AWSCloudFormationDeletionPolicy policies.DeletionPolicy `json:"-"`
// AWSCloudFormationUpdateReplacePolicy represents a CloudFormation UpdateReplacePolicy
AWSCloudFormationUpdateReplacePolicy policies.UpdateReplacePolicy `json:"-"`
// AWSCloudFormationDependsOn stores the logical ID of the resources to be created before this resource
AWSCloudFormationDependsOn []string `json:"-"`
// AWSCloudFormationMetadata stores structured data associated with this resource
AWSCloudFormationMetadata map[string]interface{} `json:"-"`
// AWSCloudFormationCondition stores the logical ID of the condition that must be satisfied for this resource to be created
AWSCloudFormationCondition string `json:"-"`
}
PlaybackConfiguration_DashConfiguration AWS CloudFormation Resource (AWS::MediaTailor::PlaybackConfiguration.DashConfiguration) See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-dashconfiguration.html
func (*PlaybackConfiguration_DashConfiguration) AWSCloudFormationType ¶
func (r *PlaybackConfiguration_DashConfiguration) AWSCloudFormationType() string
AWSCloudFormationType returns the AWS CloudFormation resource type
type PlaybackConfiguration_HlsConfiguration ¶
type PlaybackConfiguration_HlsConfiguration struct {
// ManifestEndpointPrefix AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-hlsconfiguration.html#cfn-mediatailor-playbackconfiguration-hlsconfiguration-manifestendpointprefix
ManifestEndpointPrefix *string `json:"ManifestEndpointPrefix,omitempty"`
// AWSCloudFormationDeletionPolicy represents a CloudFormation DeletionPolicy
AWSCloudFormationDeletionPolicy policies.DeletionPolicy `json:"-"`
// AWSCloudFormationUpdateReplacePolicy represents a CloudFormation UpdateReplacePolicy
AWSCloudFormationUpdateReplacePolicy policies.UpdateReplacePolicy `json:"-"`
// AWSCloudFormationDependsOn stores the logical ID of the resources to be created before this resource
AWSCloudFormationDependsOn []string `json:"-"`
// AWSCloudFormationMetadata stores structured data associated with this resource
AWSCloudFormationMetadata map[string]interface{} `json:"-"`
// AWSCloudFormationCondition stores the logical ID of the condition that must be satisfied for this resource to be created
AWSCloudFormationCondition string `json:"-"`
}
PlaybackConfiguration_HlsConfiguration AWS CloudFormation Resource (AWS::MediaTailor::PlaybackConfiguration.HlsConfiguration) See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-hlsconfiguration.html
func (*PlaybackConfiguration_HlsConfiguration) AWSCloudFormationType ¶
func (r *PlaybackConfiguration_HlsConfiguration) AWSCloudFormationType() string
AWSCloudFormationType returns the AWS CloudFormation resource type
type PlaybackConfiguration_LivePreRollConfiguration ¶
type PlaybackConfiguration_LivePreRollConfiguration struct {
// AdDecisionServerUrl AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-liveprerollconfiguration.html#cfn-mediatailor-playbackconfiguration-liveprerollconfiguration-addecisionserverurl
AdDecisionServerUrl *string `json:"AdDecisionServerUrl,omitempty"`
// MaxDurationSeconds AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-liveprerollconfiguration.html#cfn-mediatailor-playbackconfiguration-liveprerollconfiguration-maxdurationseconds
MaxDurationSeconds *int `json:"MaxDurationSeconds,omitempty"`
// AWSCloudFormationDeletionPolicy represents a CloudFormation DeletionPolicy
AWSCloudFormationDeletionPolicy policies.DeletionPolicy `json:"-"`
// AWSCloudFormationUpdateReplacePolicy represents a CloudFormation UpdateReplacePolicy
AWSCloudFormationUpdateReplacePolicy policies.UpdateReplacePolicy `json:"-"`
// AWSCloudFormationDependsOn stores the logical ID of the resources to be created before this resource
AWSCloudFormationDependsOn []string `json:"-"`
// AWSCloudFormationMetadata stores structured data associated with this resource
AWSCloudFormationMetadata map[string]interface{} `json:"-"`
// AWSCloudFormationCondition stores the logical ID of the condition that must be satisfied for this resource to be created
AWSCloudFormationCondition string `json:"-"`
}
PlaybackConfiguration_LivePreRollConfiguration AWS CloudFormation Resource (AWS::MediaTailor::PlaybackConfiguration.LivePreRollConfiguration) See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-liveprerollconfiguration.html
func (*PlaybackConfiguration_LivePreRollConfiguration) AWSCloudFormationType ¶
func (r *PlaybackConfiguration_LivePreRollConfiguration) AWSCloudFormationType() string
AWSCloudFormationType returns the AWS CloudFormation resource type
type PlaybackConfiguration_ManifestProcessingRules ¶
type PlaybackConfiguration_ManifestProcessingRules struct {
// AdMarkerPassthrough AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-manifestprocessingrules.html#cfn-mediatailor-playbackconfiguration-manifestprocessingrules-admarkerpassthrough
AdMarkerPassthrough *PlaybackConfiguration_AdMarkerPassthrough `json:"AdMarkerPassthrough,omitempty"`
// AWSCloudFormationDeletionPolicy represents a CloudFormation DeletionPolicy
AWSCloudFormationDeletionPolicy policies.DeletionPolicy `json:"-"`
// AWSCloudFormationUpdateReplacePolicy represents a CloudFormation UpdateReplacePolicy
AWSCloudFormationUpdateReplacePolicy policies.UpdateReplacePolicy `json:"-"`
// AWSCloudFormationDependsOn stores the logical ID of the resources to be created before this resource
AWSCloudFormationDependsOn []string `json:"-"`
// AWSCloudFormationMetadata stores structured data associated with this resource
AWSCloudFormationMetadata map[string]interface{} `json:"-"`
// AWSCloudFormationCondition stores the logical ID of the condition that must be satisfied for this resource to be created
AWSCloudFormationCondition string `json:"-"`
}
PlaybackConfiguration_ManifestProcessingRules AWS CloudFormation Resource (AWS::MediaTailor::PlaybackConfiguration.ManifestProcessingRules) See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-manifestprocessingrules.html
func (*PlaybackConfiguration_ManifestProcessingRules) AWSCloudFormationType ¶
func (r *PlaybackConfiguration_ManifestProcessingRules) AWSCloudFormationType() string
AWSCloudFormationType returns the AWS CloudFormation resource type
Source Files
¶
- aws-mediatailor-playbackconfiguration.go
- aws-mediatailor-playbackconfiguration_admarkerpassthrough.go
- aws-mediatailor-playbackconfiguration_availsuppression.go
- aws-mediatailor-playbackconfiguration_bumper.go
- aws-mediatailor-playbackconfiguration_cdnconfiguration.go
- aws-mediatailor-playbackconfiguration_dashconfiguration.go
- aws-mediatailor-playbackconfiguration_hlsconfiguration.go
- aws-mediatailor-playbackconfiguration_liveprerollconfiguration.go
- aws-mediatailor-playbackconfiguration_manifestprocessingrules.go